aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/voip.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/voip.h')
-rw-r--r--lib/csapi/voip.h60
1 files changed, 24 insertions, 36 deletions
diff --git a/lib/csapi/voip.h b/lib/csapi/voip.h
index bb858499..38904f60 100644
--- a/lib/csapi/voip.h
+++ b/lib/csapi/voip.h
@@ -6,41 +6,29 @@
#include "jobs/basejob.h"
-#include <QtCore/QJsonObject>
-
-namespace QMatrixClient
-{
- // Operations
+namespace Quotient {
+/*! \brief Obtain TURN server credentials.
+ *
+ * This API provides credentials for the client to use when initiating
+ * calls.
+ */
+class QUOTIENT_API GetTurnServerJob : public BaseJob {
+public:
/// Obtain TURN server credentials.
- ///
- /// This API provides credentials for the client to use when initiating
- /// calls.
- class GetTurnServerJob : public BaseJob
- {
- public:
- explicit GetTurnServerJob();
-
- /*! Construct a URL without creating a full-fledged job object
- *
- * This function can be used when a URL for
- * GetTurnServerJob is necessary but the job
- * itself isn't.
- */
- static QUrl makeRequestUrl(QUrl baseUrl);
-
- ~GetTurnServerJob() override;
-
- // Result properties
-
- /// The TURN server credentials.
- const QJsonObject& data() const;
-
- protected:
- Status parseJson(const QJsonDocument& data) override;
-
- private:
- class Private;
- QScopedPointer<Private> d;
- };
-} // namespace QMatrixClient
+ explicit GetTurnServerJob();
+
+ /*! \brief Construct a URL without creating a full-fledged job object
+ *
+ * This function can be used when a URL for GetTurnServerJob
+ * is necessary but the job itself isn't.
+ */
+ static QUrl makeRequestUrl(QUrl baseUrl);
+
+ // Result properties
+
+ /// The TURN server credentials.
+ QJsonObject data() const { return fromJson<QJsonObject>(jsonData()); }
+};
+
+} // namespace Quotient